pm4py.objects.conversion.heuristics\_net.variants package
=========================================================

Submodules
----------

pm4py.objects.conversion.heuristics\_net.variants.to\_petri\_net module
-----------------------------------------------------------------------

.. automodule:: pm4py.objects.conversion.heuristics_net.variants.to_petri_net
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.objects.conversion.heuristics_net.variants
   :members:
   :undoc-members:
   :show-inheritance:
